@@ -1,6 +1,6 @@
 wfe <- function (formula, data, treat = "treat.name",
                  unit.index, time.index = NULL, method = "unit",
-                 qoi = c("ate", "att"), estimator = NULL, C.it = NULL,
+                 qoi = "ate", estimator = NULL, C.it = NULL,
                  hetero.se = TRUE, auto.se = TRUE,
                  White = TRUE, White.alpha = 0.05,
                  verbose = TRUE, unbiased.se = FALSE, unweighted = FALSE,
@@ -568,7 +568,7 @@ wfe <- function (formula, data, treat = "treat.name",
 
 
     z <- list(coefficients = coef.wls,
-              x = x[,-1],
+              x = x[,-1,drop=FALSE],
               y = y,
               mf = mf,
               call = wfe.call,
@@ -576,7 +576,7 @@ wfe <- function (formula, data, treat = "treat.name",
               se = sqrt(diag(var.cov)),
               sigma = sqrt(sigma2),
               df = d.f,
-              residuals = y - (x[,-1] %*% coef.wls),
+              residuals = y - (x[,-1,drop=FALSE] %*% coef.wls),
               W = W,
               uniq.n.units = J.u,
               units = units,
@@ -1545,7 +1545,7 @@ wfe <- function (formula, data, treat = "treat.name",
 ### Saving results
 
       z <- list(coefficients = coef.wls,
-                x = x[,-1],
+                x = x[,-1,drop=FALSE],
                 y = y,
                 mf = mf,
                 call = wfe.call,
@@ -1553,7 +1553,7 @@ wfe <- function (formula, data, treat = "treat.name",
                 se = se.did,
                 sigma = try(sqrt(sigma2)),
                 df = d.f,
-                residuals = y - (x[,-1] %*% coef.wls),
+                residuals = y - (x[,-1,drop=FALSE] %*% coef.wls),
                 W = W,
                 units = units,
                 times = times,
